pub type ExportResult<T> = Result<T, ExportError>;Expand description
Type alias for a result with an export error
Aliased Type
pub enum ExportResult<T> {
Ok(T),
Err(ExportError),
}pub type ExportResult<T> = Result<T, ExportError>;Type alias for a result with an export error
pub enum ExportResult<T> {
Ok(T),
Err(ExportError),
}